==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/ts/Edit_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translatorcomment>--exact match--
--file: AppPreferences_pt.ts--
Preferências do &amp;Aplicativo
Preferências do aplicativo
Preferências Gerais do Aplicativo</translatorcomment>
        <translation>Preferências do Aplicativo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translatorcomment>--exact match--
--file: DrawingPreferences_pt.ts--
&amp;Preferências do Desenho Atual...
&amp;Preferências do Desenho Atual
Preferências do Desenho Atual...</translatorcomment>
        <translation>Preferências de Desenho</translation>
    </message>
    <message>
        <location line="+312"/>
        <source>Restart required</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>É necessário reiniciar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Por favor, reinicie o QCAD
para que as mudanças de preferências entrem em vigor</translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translatorcomment>--ignored case--
--file: CreateBlock_pt.ts--
Indique o ponto de referência
Copie entidade com ponto de referência  para o clipboard</translatorcomment>
        <translation>Ponto de referência</translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation>Ferramentas de Edição</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation>Exiba as ferramentas de edição</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translatorcomment>--exact match--
--file: qcad_pt.ts--
&amp;Edição
&amp;Edite bloco</translatorcomment>
        <translation>&amp;Edição</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+85"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
&amp;Preferências
Preferências
Preferências do &amp;Aplicativo</translatorcomment>
        <translation>Preferências</translation>
    </message>
    <message>
        <location line="-88"/>
        <source>Filter</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Reduz o ruído em no(s) bitmap(s) seleccionado(s) usando um filtro de
eliminação de picos de ruído
Administrar efeitos de filtro SVG</translatorcomment>
        <translation>Filtro</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Clear Search</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Limpe a Pesquisa</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Expand Tree</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Expanda a  Árvore</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Recolha a Árvore</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Restaure para Valores Padrão</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/ts/Edit_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translatorcomment>--exact match--
--file: AppPreferences_pt.ts--
Preferências do &amp;Aplicativo
Preferências do aplicativo
Preferências Gerais do Aplicativo</translatorcomment>
        <translation>Preferências do Aplicativo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translatorcomment>--exact match--
--file: DrawingPreferences_pt.ts--
&amp;Preferências do Desenho Atual...
&amp;Preferências do Desenho Atual
Preferências do Desenho Atual...</translatorcomment>
        <translation>Preferências de Desenho</translation>
    </message>
    <message>
        <location line="+300"/>
        <source>Apply preferences</source>
        <translation>Aplicar preferências</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Restart required</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>É necessário reiniciar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Por favor, reinicie o QCAD
para que as mudanças de preferências entrem em vigor.</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Defaults for </source>
        <translation>Padrões para</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>These are default preferences for new drawings.</source>
        <translation>Estas são as preferências padrão para novos desenhos.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Preferences of the current drawing can be changed under&lt;br/&gt;&lt;i&gt;Edit &amp;gt; Drawing Preferences&lt;/i&gt;.</source>
        <translation>Preferências do desenho atual pode ser alterado sob&lt;br/&gt;&lt;i&gt;Edição &amp;gt; Preferências de Desenho&lt;/i&gt;.</translation>
    </message>
    <message>
        <source>You are changing default preferences for new drawings.</source>
        <translation type="vanished">Estas são as preferências padrão para novos desenhos.</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Changes will affect new drawings but NOT the current drawing.</source>
        <translation>Mudanças afetarão novos desenhos, mas não o desenho atual.</translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translatorcomment>--ignored case--
--file: CreateBlock_pt.ts--
Indique o ponto de referência
Copie entidade com ponto de referência  para o clipboard</translatorcomment>
        <translation>Ponto de referência</translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation>Ferramentas de Edição</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation>Exiba as ferramentas de edição</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translatorcomment>--exact match--
--file: qcad_pt.ts--
&amp;Edição
&amp;Edite bloco</translatorcomment>
        <translation>&amp;Edição</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+71"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
&amp;Preferências
Preferências
Preferências do &amp;Aplicativo</translatorcomment>
        <translation>Preferências</translation>
    </message>
    <message>
        <location line="-74"/>
        <source>Filter</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Reduz o ruído em no(s) bitmap(s) seleccionado(s) usando um filtro de
eliminação de picos de ruído
Administrar efeitos de filtro SVG</translatorcomment>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>Clear Search</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Limpe a Pesquisa</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Expand Tree</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Expanda a  Árvore</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Recolha a Árvore</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Restaure para Valores Padrão</translation>
    </message>
</context>
</TS>
